@@ -9,16 +9,15 @@
 #' batch_price("batch_id")
 #' }
 
-batch_price <- function(batch_id="")
-{
-    app_token = getOption("CaptricityToken")
-    if( is.null(app_token)) stop("Please set application token using set_token('app_token').")
-    
-    if ( is.null(batch_id) | batch_id=="") stop("Provide a Valid Batch ID.")
+batch_price <- function(batch_id="") {
+
+    captr_CHECKAUTH()
+   
+    if (is.null(batch_id) | identical(batch_id, "")) stop("Provide a Valid Batch ID.")
 
     h <- new_handle()
     handle_setopt(h,  customrequest = "GET")
-    handle_setheaders(h, "Captricity-API-Token" = app_token)
+    handle_setheaders(h, "Captricity-API-Token" = Sys.getenv('CaptricityToken'))
 
     tag_con    <- curl_fetch_memory(paste0("https://shreddr.captricity.com/api/v1/batch/", batch_id, "/price"), handle=h)
     tag        <- fromJSON(rawToChar(tag_con$content))
