@@ -11,12 +11,12 @@
 
 create_batch <- function(batch_name="")
 {
-    app_token = getOption("CaptricityToken")
-    if( is.null(app_token)) stop("Please set application token using set_token('app_token').")
     
+    captr_CHECKAUTH()
+  
     h <- new_handle()
     handle_setopt(h,  customrequest = "POST")
-    handle_setheaders(h, "Captricity-API-Token" = app_token)
+    handle_setheaders(h, "Captricity-API-Token" = Sys.getenv('CaptricityToken'))
     handle_setform(h, name= batch_name)
 
     tag_con    <- curl_fetch_memory("https://shreddr.captricity.com/api/v1/batch/", handle=h)
